@@ -146,7 +146,7 @@ private:
 	{
 		return (str1.isEmpty() && str2.isEmpty()) || (str1 == str2);
 	} ;
-	typedef enum eqFlagsType
+	enum eqFlagsType
 	{
 		eqFlagsName=0x1,
 		eqFlagsAdress=0x2,
