@@ -42,7 +42,7 @@ class TQTimer;
 class KPilotLink;
 
 
-typedef struct conflictEntry {
+struct conflictEntry {
 	TQLabel*dbname;
 	TQComboBox* resolution;
 	TQPushButton*info;
