@@ -32,12 +32,12 @@
 #include "plugin.h"
 
 class TimeWidget;
-class KAboutData;
+class TDEAboutData;
 
 class TimeWidgetConfig : public ConduitConfigBase
 {
 Q_OBJECT
-  TQ_OBJECT
+  
 public:
 	TimeWidgetConfig(TQWidget *parent, const char *);
 	virtual void commit();
@@ -45,7 +45,7 @@ public:
 	static ConduitConfigBase *create(TQWidget *,const char *);
 protected:
 	TimeWidget *fConfigWidget;
-	KAboutData *fAbout;
+	TDEAboutData *fAbout;
 } ;
 
 #endif
